@@ -11,15 +11,11 @@
   return(invisible(0))
 }
 
-
-".bilinearformXAY"<-geoR:::.bilinearformXAY 
-".check.locations"<-geoR:::.check.locations
-".cond.sim"<-geoR:::.cond.sim
-".cor.number"<-geoR:::.cor.number
-".diagquadraticformXAX"<-geoR:::.diagquadraticformXAX
-## ".geoR_inout"<-geoR:::.geoR_inout
-".ldots.set"<-geoR:::.ldots.set
-".prepare.graph.krige.bayes"<-geoR:::.prepare.graph.krige.bayes
-".solve.geoR"<-geoR:::.solve.geoR
-"hist.krige.bayes"<-geoR:::hist.krige.bayes
-## "image.kriging"<-geoR:::image.kriging
+".bilinearformXAY"<- function(...) geoR:::.bilinearformXAY(...)
+".check.locations"<- function(...) geoR:::.check.locations(...)
+".cond.sim"<- function(...) geoR:::.cond.sim(...)
+".cor.number"<- function(...) geoR:::.cor.number(...)
+".diagquadraticformXAX"<- function(...) geoR:::.diagquadraticformXAX(...)
+".geoR_inout"<- function(...) geoR:::.geoR_inout(...)
+".ldots.set"<- function(...) geoR:::.ldots.set(...)
+".solve.geoR"<- function(...) geoR:::.solve.geoR(...)
